@@ -5,7 +5,9 @@
 #' @param base_family base font family
 #' @export
 theme_white_f <- function(base_size = 12, base_family = ""){
-  ggplot2::theme_bw(base_size = base_size, base_family = base_family) %+replace%
+  ggplot2::theme_bw(
+    base_size = base_size, base_family = base_family
+  ) %+replace%
     ggplot2::theme(
       legend.background = ggplot2::element_blank(),
       legend.key = ggplot2::element_blank(),
@@ -27,24 +29,27 @@ theme_white_f <- function(base_size = 12, base_family = ""){
 #' 
 #' @param data data frame with longitude, latitude and group coordinates of a territory (polygons)
 #' @param mapping Aesthetic mappings, as character strings (\code{link{ggplot2::aes_string}}). Defaults are \code{x = "long"}, \code{y = "lat"} and \code{group = "group"} (these work with every element of the list \code{shp_df} of ggswissmaps)
+#' @param caption text to include in the lower right corner of the map (default: "Boundaries: BFS GEOSTAT / swisstopo")
 #' 
 #'  
 #' @examples 
 #' data(shp_df)
 #' maps2_(data = shp_df[[1]])
 #' @export
-maps2_ <- 
-  function(data,
-           mapping = 
-             ggplot2::aes_string(x = "long",
-                                 y = "lat",
-                                 group = "group")){
-    ggplot2::ggplot(data = data, mapping = mapping) +
+maps2_ <- function(data,
+                   mapping = ggplot2::aes(
+                     x = .data[["long"]],
+                     y = .data[["lat"]],
+                     group = .data[["group"]]
+                   ),
+                   caption = "Boundaries: BFS GEOSTAT / swisstopo") {
+  ggplot2::ggplot(data = data, mapping = mapping) +
     ggplot2::geom_path() +
     ggplot2::coord_equal() +
-      theme_white_f()
+      theme_white_f() +
+      ggplot2::labs(x = NULL, y = NULL, caption = caption)
 }
 
 # data(shp_df)
 # maps2_(data = shp_df[[1]])
-# maps2 <- lapply(shp_df, maps2_)
\ No newline at end of file
+# maps2 <- lapply(shp_df, maps2_)
